@@ -1,5 +1,5 @@
 /*-*-c++-*-
- * $Id: rfsv16.cc,v 1.27 2008/03/13 17:03:00 rrt Exp $
+ * $Id$
  *
  * This file is part of plptools.
  *
@@ -55,7 +55,8 @@ fopen(u_int32_t attr, const char *name, u_int32_t &handle)
     bufferStore a;
     string realName	= convertSlash(name);
 
-    a.addWord(attr & 0xFFFF);
+    // Allow random access, rather than forcing the caller to ask for it
+    a.addWord((P_FRANDOM | attr) & 0xFFFF);
     a.addStringT(realName.c_str());
     if (!sendCommand(FOPEN, a))
 	return E_PSI_FILE_DISC;
@@ -68,7 +69,6 @@ fopen(u_int32_t attr, const char *name, u_int32_t &handle)
     return res;
 }
 
-// internal
 Enum<rfsv::errs> rfsv16::
 mktemp(u_int32_t &handle, string &tmpname)
 {
